Zero-dependency library with no-std support for writing parsers in a concise functional style & with rich error-reporting.
Kinds of errors are distinguished via a user-defined Reason type, which signals what did
a parser expect.
A ParsingError can also have no reason, which will mean that the error is recoverable.
Some built-in parsers can have core::convert::Infallible as their error reason,
which means that any error the parser may ever return is recoverable.
The distinction between recoverable & fatal errors is important for parsers that need to try multiple options.
Error reporting with precise location in the source is facilitated by
constructing a FullParsingError with methods such as
Parser::with_full_error, ParsingError::with_src_loc
Modules
- pattern
- Abstractions for working with patterns.
- tuple
- This module contains utilities for working with generic tuples, such as:
- utils
- This module provides utility functions for locating pointers into text.
Macros
- any
- Make a parser that tries any of the provided paths.
- call
- Generates a closure that calls a function with a tuple’s contents as it arguments. The input can be anything as long as the last token contains all the arguments parenthesized.
- from_
tuple - Generates a closure that constructs a struct from a tuple. The struct fields must be exactly in the order in which they’re expected to be in the tuple.
- nonzero
- Create a non-zero integer from a literal.
Structs
- Full
Parsing Error - A final error with information about where in the source did the error occur.
- Iter
- Iterator returned by
Parser::iter - Parsing
Error - Error returned by a parser.
Traits
- Input
- This trait represents input that can be parsed by a Parser and/or matched by a Pattern
- Parser
- The core of the crate, a trait representing a function that takes some input and
returns either a tuple of (the rest of the input, the output) or a
ParsingError.
Functions
- parse_
char - Parses any 1 character from the input.
Type Aliases
- Parsing
Result - The result of a parser.